@@ -17,9 +17,18 @@
 # MA  02110-1301, USA.  A copy of the GNU General Public License is
 # also available at http://www.gnu.org/copyleft/gpl.html.
 
-from ovirt_config_setup.snmp import enable_snmpd
-import ovirtnode.ovirtfunctions as _functions
+from ovirt.node.utils.console import TransactionProgress
+from ovirt.node.setup.snmp import snmp_model
+from ovirt.node.utils import system
 
-args = _functions.get_cmdline_args()
-if "snmp_password" in args:
-        enable_snmpd(args["snmp_password"])
+args = system.kernel_cmdline_arguments()
+
+if __name__ == "__main__":
+    snmp = snmp_model.SNMP()
+    if "snmp_password" in args and len(args["snmp_password"]) > 0:
+        snmp.update(enabled=True)
+        tx = snmp.transaction(snmp_password=args["snmp_password"])
+        TransactionProgress(tx, is_dry=False).run()
+        # clear ovirt_snmp_passwd from /etc/default/ovirt
+        pw_keys = ("OVIRT_SNMP_PASSWORD",)
+        snmp.clear(keys=pw_keys)
