@@ -23,13 +23,23 @@ from ovirtnode.storage import *
 from ovirtnode.install import *
 from ovirtnode.network import *
 from ovirtnode.log import *
-from ovirtnode.kdump import *
 from ovirt.node.utils.console import TransactionProgress
 from ovirt.node.utils import system
-from ovirt.node.utils import security, storage
+from ovirt.node.utils import security, storage, hooks
 from ovirt.node.config import defaults
+from ovirt.node.utils.system import which, kernel_cmdline_arguments, \
+    SystemRelease
 import logging
 import sys
+import os
+import time
+
+
+class PrepareInstallation(Transaction.Element):
+    title = "Prepare installation"
+
+    def commit(self):
+        defaults.ConfigVersion().set_to_current()
 
 
 class ConfigureNetworking(Transaction.Element):
@@ -159,7 +169,29 @@ class ConfigureKdump(Transaction.Element):
     title = "Configuring KDump"
 
     def commit(self):
-        kdump_auto()
+        try:
+            model = defaults.KDump()
+
+            if "OVIRT_KDUMP_SSH" in OVIRT_VARS and \
+                    "OVIRT_KDUMP_SSH_KEY" in OVIRT_VARS:
+                model.configure_ssh(OVIRT_VARS["OVIRT_KDUMP_SSH"],
+                                    OVIRT_VARS["OVIRT_KDUMP_SSH_KEY"])
+            elif "OVIRT_KDUMP_NFS" in OVIRT_VARS:
+                model.configure_nfs(OVIRT_VARS["OVIRT_KDUMP_NFS"])
+            elif "OVIRT_DISABLE_KDUMP" in OVIRT_VARS:
+                model.configure_disable()
+            else:
+                model.configure_local()
+
+            tx = model.transaction()
+            tx()
+
+        except:
+            kdump_args = ["OVIRT_KDUMP_SSH", "OVIRT_KDUMP_SSH_KEY",
+                          "OVIRT_KDUMP_NFS", "OVIRT_KDUMP_LOCAL"]
+            logger.warning("Unknown kdump configuration: %s" % \
+                            " ".join([x for x in kdump_args if \
+                                      x in OVIRT_VARS]))
 
 
 class InstallBootloader(Transaction.Element):
@@ -175,16 +207,30 @@ class InstallBootloader(Transaction.Element):
         install = Install()
         if not install.ovirt_boot_setup():
             raise RuntimeError("Bootloader Installation Failed")
-
         cfgfile.write(cfg)
 
 
+class RunHooks(Transaction.Element):
+    """Run post-install hooks
+    e.g. to avoid reboot loops using Cobbler PXE only once
+    Cobbler XMLRPC post-install trigger (XXX is there cobbler SRV record?):
+    wget "http://192.168.50.2/cblr/svc/op/trig/mode/post/system/$(hostname)"
+      -O /dev/null
+    """
+    title = "Running Hooks"
+
+    def commit(self):
+        hooks.Hooks.post_auto_install()
+
+
 if __name__ == "__main__":
     if "--debug" in sys.argv:
         logging.basicConfig(level=logging.DEBUG)
 
     tx = Transaction("Automatic Installation")
 
+    tx.append(PrepareInstallation())
+
     # setup network before storage for iscsi installs
     if is_iscsi_install():
         tx.append(ConfigureNetworking())
@@ -221,7 +267,8 @@ if __name__ == "__main__":
 
     tx.append(ConfigureLogging())
 
-    tx.append(ConfigureCollectd())
+    if not SystemRelease().is_el():
+        tx.append(ConfigureCollectd())
 
     tx.append(PerformInstallation())  # FIXME needed??
 
@@ -230,7 +277,15 @@ if __name__ == "__main__":
     if not is_stateless():
         tx.append(InstallBootloader())
 
+    tx.append(RunHooks())
+
     TransactionProgress(tx, is_dry=False).run()
     print "Installation and Configuration Completed"
 
+    reboot_delay = kernel_cmdline_arguments().get("reboot_delay", None)
+    if reboot_delay:
+        print "Reboot Scheduled in %s seconds later" % reboot_delay
+        time.sleep(int(reboot_delay))
+        os.system(which("reboot"))
+
     # python will exit with 1 if an exception occurs
