@@ -24,7 +24,7 @@
 . /etc/init.d/functions
 . /usr/libexec/ovirt-functions
 
-. /usr/share/dracut/modules.d/91ovirtnode/ovirt-boot-functions
+. /usr/lib/dracut/modules.d/91ovirtnode/ovirt-boot-functions
 
 
 VAR_SUBSYS_OVIRT_EARLY=/var/lock/subsys/ovirt-early
@@ -37,6 +37,8 @@ BONDING_MODCONF_FILE=/etc/modprobe.d/bonding
 AUGTOOL_CONFIG=/var/tmp/augtool-config
 EARLY_DIR=/etc/ovirt-early.d
 
+HOOK_ON_BOOT_DIR=/usr/libexec/ovirt-node/hooks/on-boot
+
 # Drop to a shell
 emergency_shell() {
     plymouth --hide-splash
@@ -181,7 +183,7 @@ from ovirtnode.install import Install
 install = Install()
 install.ovirt_boot_setup()
 from ovirt.node.config import migrate
-migrate.MigrateConfigs().translate_all()
+migrate.ConfigMigrationRunner().run_if_necessary()
 EOP
                 fi
             fi
@@ -204,8 +206,6 @@ start_ovirt_early () {
         log "Starting ovirt-early"
         _start_ovirt_early
         RETVAL=$?
-        # TEMP fix broken libvirtd.conf
-        sed -c -i '/^log_filters=/d' /etc/libvirt/libvirtd.conf
         log "Completed ovirt-early"
     } >> $OVIRT_LOGFILE 2>&1
     return $RETVAL
@@ -240,6 +240,7 @@ _start_ovirt_early () {
     #   use_strong_rng=<bytes>
     #   nfsv4_domain=domain
     #   logrotate_max_size=number
+    #   reboot_delay=number
 
     #   BOOTIF=link|eth*|<MAC> (appended by pxelinux)
     # network boot interface is assumed to be on management network where
@@ -495,7 +496,7 @@ _start_ovirt_early () {
                     for d in $appvgdisks; do
                         did="$(IFS="$oldIFS" parse_disk_id "$d")"
                         if [ -z "$did" ]; then
-                            autoinstall_failed
+                            autoinstall_failed "Reason: AppVG"
                         fi
                         if [ -n "$init_app" ]; then
                             init_app="$init_app${SEP}$did"
@@ -595,11 +596,6 @@ _start_ovirt_early () {
                 /usr/sbin/usermod -p $(grep ^root /etc/shadow | sed 's/:/ /g' | awk '{print $2}') admin
                 persist /etc/shadow /etc/passwd
             fi
-            if ! grep -q ^cim /etc/passwd; then
-                unmount_config /etc/passwd /etc/shadow
-                useradd -G sfcb -g cim -s /sbin/nologin cim
-                persist /etc/shadow /etc/passwd
-            fi
             ;;
             standalone=no | standalone=0 | ovirt_standalone=no | ovirt_standalone=0)
             standalone=0
@@ -645,15 +641,6 @@ _start_ovirt_early () {
                 adminpw=$rootpw
             fi
             ;;
-            cim_passwd=*)
-            cim_passwd=${i#cim_passwd=}
-            ;;
-            cim_enabled=0 | cim_enabled=no)
-            cim_enabled=0
-            ;;
-            enable_cim* | enable_cim | cim_enabled* | cim_enabled)
-            cim_enabled=1
-            ;;
             snmp_password=*)
             snmp_password=${i#snmp_password=}
             ;;
@@ -685,12 +672,21 @@ _start_ovirt_early () {
             dns=${i#dns=}
             ;;
             ntp=*)
-            ntp=${i#ntp=}
+            ntp=$(printf $i|python -c "`cat << EOP
+import sys
+from ovirt.node.config.defaults import Timeservers
+validservers = []
+for line in sys.stdin:
+    # remove the leading ntp=...
+    print ",".join(Timeservers.filter_valid_servers(line[4:].strip().split(",")))
+EOP
+`")
             ;;
             network_layout=*)
             network_layout=${i#network_layout=}
             ;;
-            bond_setup=*)
+            bond_setup=* | bond=*)
+            i=${i#bond=}
             i=${i#bond_setup=}
             eval $(printf $i|awk -F: '{print "bond_name="$1; print "bond_slaves="$2; print "bond_options="$3;}')
             ;;
@@ -731,9 +727,21 @@ _start_ovirt_early () {
             crashkernel=*)
             bootparams="$bootparams $i"
             ;;
+            console=*)
+            bootparams="$bootparams $i"
+            ;;
             kdump_nfs=*)
             kdump_nfs=${i#kdump_nfs=}
             ;;
+            disable_kdump*)
+            disable_kdump="Y"
+            ;;
+            kdump_ssh=*)
+            kdump_ssh=${i#kdump_ssh=}
+            ;;
+            kdump_ssh_key=*)
+            kdump_ssh_key=${i#kdump_ssh_key=}
+            ;;
             iscsi_name=*)
             iscsi_name=${i#iscsi_name=}
             ;;
@@ -849,9 +857,11 @@ EOP
         reboot
     fi
 
+    # Keep a pointer open to the early boot logs
+    mkdir /tmp/early-logs && ( mount --bind /var/log /tmp/early-logs && mount --make-rprivate /tmp/early-logs ; )
 
     # save boot parameters as defaults for ovirt-config-*
-    params="bootif init init_app vol_boot_size vol_efi_size vol_swap_size vol_root_size vol_config_size vol_logging_size vol_data_size vol_swap2_size vol_data2_size crypt_swap crypt_swap2 upgrade standalone overcommit ip_address ip_netmask ip_gateway ipv6 dns ntp vlan ssh_pwauth syslog_server syslog_port collectd_server collectd_port bootparams hostname firstboot runtime_mode kdump_nfs iscsi_name snmp_password install netconsole_server netconsole_port stateless cim_enabled wipe_fakeraid iscsi_init iscsi_target_name iscsi_target_host iscsi_target_port iscsi_install network_layout bond_name bond_slaves bond_options tuned_profile nfsv4_domain use_strong_rng disable_aes_ni keyboard_layout logrotate_max_size"
+    params="bootif init init_app vol_boot_size vol_efi_size vol_swap_size vol_root_size vol_config_size vol_logging_size vol_data_size vol_swap2_size vol_data2_size crypt_swap crypt_swap2 upgrade standalone overcommit ip_address ip_netmask ip_gateway ipv6 dns ntp vlan ssh_pwauth syslog_server syslog_port collectd_server collectd_port bootparams hostname firstboot runtime_mode kdump_nfs disable_kdump kdump_ssh kdump_ssh_key iscsi_name snmp_password install netconsole_server netconsole_port stateless wipe_fakeraid iscsi_init iscsi_target_name iscsi_target_host iscsi_target_port iscsi_install network_layout bond_name bond_slaves bond_options tuned_profile nfsv4_domain use_strong_rng disable_aes_ni keyboard_layout logrotate_max_size"
     # mount /config unless firstboot is forced
     if [ "$firstboot" != "1" ]; then
         mount_config
@@ -876,8 +886,20 @@ EOP
         value=$(ptr $p)
         if [ -n "$value" -o $p = 'init' -o $p = 'upgrade' -o $p = 'install' ]; then
             log "Updating OVIRT_$PARAM to '$value'"
-            echo "set /files$OVIRT_DEFAULTS/OVIRT_$PARAM '\"$value\"'" \
-                >> $tmpaug
+            if [[ ${PARAM} == "MANAGEMENT_SERVER" ]]; then
+                value=`echo ${value} | sed 's/http\(\|s\):\/\///g'`
+            fi
+            if [[ ${PARAM} == "MANAGEMENT_SERVER" && ${value} == *:* ]]; then
+                MGMSERVER=${value%:*}
+                MGMPORT=${value#*:}
+                echo "set /files$OVIRT_DEFAULTS/OVIRT_MANAGEMENT_SERVER '\"${MGMSERVER}\"'" \
+                    >> $tmpaug
+                echo "set /files$OVIRT_DEFAULTS/OVIRT_MANAGEMENT_PORT '\"${MGMPORT}\"'" \
+                    >> $tmpaug
+            else
+                echo "set /files$OVIRT_DEFAULTS/OVIRT_$PARAM '\"$value\"'" \
+                    >> $tmpaug
+            fi
         fi
     done
     # block accidental bootif changes on upgrades
@@ -897,17 +919,14 @@ EOP
     fi
 
     [[ -f "/etc/udev/rules.d/71-persistent-node-net.rules" ]] && {
-        # Rename the interfaces after bind-mounting the udev rules, rhbz#831658
-        rm -f /etc/udev/rules.d/70-persistent-net.rules
-        udevadm control --reload-rules
-        udevadm trigger --action=add --subsystem-match=net
+        [[ $(rpm -E "%{?rhel"}) = 6 ]] || [[ $(rpm -E "%{?centos}") = 6 ]] && {
+            # Rename the interfaces after bind-mounting the udev rules, rhbz#831658
+            rm -f /etc/udev/rules.d/70-persistent-net.rules
+            udevadm control --reload-rules
+            udevadm trigger --action=add --subsystem-match=net
+        }
     }
 
-    if [ -n "$cim_passwd" ]; then
-        log "Setting temporary cim password"
-        unmount_config /etc/passwd /etc/shadow
-        /usr/sbin/usermod -p "$cim_passwd" cim
-    fi
     if [ -n "$adminpw" ]; then
         log "Setting temporary admin password"
         unmount_config /etc/passwd /etc/shadow
@@ -999,6 +1018,16 @@ EOF
 from ovirt.node.utils import firewall
 firewall.process_plugins()
 EOP
+
+    if [[ -d "$HOOK_ON_BOOT_DIR" ]] && [[ "$(ls -A $HOOK_ON_BOOT_DIR)" ]];
+    then
+        for handler in "$HOOK_ON_BOOT_DIR"/*;
+        do
+            log "Running handler: $handler"
+            "$handler" >> $OVIRT_LOGFILE 2>&1
+        done
+    fi
+
     return 0
 }
 
@@ -1127,13 +1156,31 @@ trap '__st=$?; stop_log; exit $__st' 0
 #trap 'exit $?' 1 2 13 15
 
 check_version(){
-    if [ -e "/dev/HostVG/Root" ]; then
-    log "                                          "
-    log "   Major version upgrades are not allowed."
-    log "   Please uninstall existing version and reinstall."
-    log "   Press Enter to drop to emergency shell."
-    read < /dev/console
-    bash < /dev/console
+    mount_liveos
+    if [ -e "/live/syslinux" ]; then
+      syslinux=syslinux
+    elif [ -e "/live/isolinux" ]; then
+      syslinux=isolinux
+    else
+      syslinux=
+    fi
+
+    . /liveos/version
+    local current_version=$VERSION
+    local current_major=$(echo $VERSION|cut -d. -f1)
+    # image version
+    . /live/$syslinux/version
+    local new_major=$(echo $VERSION|cut -d. -f1)
+    # only N.x -> N.y upgrades are allowed
+    if [ "$current_major" != "$new_major" ]; then
+        log "                                          "
+        log "   Major version upgrades are not allowed."
+        log "   Installed version: $current_version"
+        log "   New version      : $VERSION"
+        log "   Please uninstall existing version and reinstall."
+        log "   Press Enter to drop to emergency shell."
+        read < /dev/console
+        bash < /dev/console
     fi
 }
 
@@ -1163,6 +1210,13 @@ start_ovirt_firstboot ()
         debugmode && AIARGS="--debug"
         /usr/libexec/ovirt-auto-install $AIARGS
         rc=$?
+
+        # Greedy approach to remove eventual password variables
+        # after auto installation. Done here to workaround nasty
+        # caching of OVIRT_VARS in .py files.
+        # https://bugzilla.redhat.com/show_bug.cgi?id=1062541
+        sed -ci "/.*PASSWORD.*=/ d" /etc/default/ovirt || :
+
         breakpoint "post-installer"
         # Handle Log file
         if [ -f $OVIRT_TMP_LOGFILE ]; then
@@ -1170,11 +1224,11 @@ start_ovirt_firstboot ()
             rm -f $OVIRT_TMP_LOGFILE
         fi
         if [ $rc -ne 0 ]; then
-            autoinstall_failed
+            autoinstall_failed "Reason: Transactio issue"
         fi
     elif [ "$auto_install" = "2" ]; then
         echo "Device specified in storage_init does not exist"
-        autoinstall_failed
+        autoinstall_failed "Reason: Storage device issue"
     fi
 
     if is_stateless; then
@@ -1191,15 +1245,17 @@ start_ovirt_firstboot ()
 from ovirtnode.install import Install
 install = Install()
 install.ovirt_boot_setup()
-from ovirt.node.config import migrate
-migrate.MigrateConfigs().translate_all()
 EOP
         fi
         if [ $? -ne 0 ]; then
-            autoinstall_failed
+            autoinstall_failed "Reason: Boot setup issue"
         fi
         disable_firstboot
-        ovirt_store_firstboot_config || autoinstall_failed
+        ovirt_store_firstboot_config
+        retval=$?
+        if [ $retval -eq 1 ] || [ $retval -eq 2 ]; then
+            autoinstall_failed "Reason: Store firstboot issue ($retval)"
+        fi
 
         # rhbz#920208
         # the sysd-upd-utmp-shutdown.service (see below) is pulling in the var-log.mount unit.
@@ -1213,7 +1269,7 @@ EOP
         reboot
 
         if [ $? -ne 0 ]; then
-            autoinstall_failed
+            autoinstall_failed "Reason: Reboot ..."
         fi
         return 1
     fi
@@ -1315,6 +1371,11 @@ start_ovirt_post() {
         swapon -a
         mount -a
 
+        if [ -f /etc/rhev-hypervisor-release ]; then
+            # force update rhn profile on boot for upgrades
+            rhn_check
+        fi
+
         # Synchronize logs
         log "Synchronizing log files"
         logsync_TMPDIR=$(mktemp -d)
@@ -1329,6 +1390,9 @@ EOP
         umount ${logsync_TMPDIR}/squash
         rm -rf ${logsync_TMPDIR}
 
+        # Migrate config files if needed
+        migrate_node_config
+
         # Re-load keyboard settings
         load_keyboard_config
 
@@ -1338,8 +1402,11 @@ EOP
         # Create a minimalistic /etc/hosts if it's empty, rhbz#829753
         create_minimal_etc_hosts_file
 
-        # Restart jorunald to pick up /var/log/journal
-        service systemd-journald restart
+        if [ -f /usr/lib/systemd/system/systemd-journald.service ];
+        then
+            # Restart jorunald to pick up /var/log/journal
+            /bin/systemctl restart systemd-journald.service
+        fi
 
         # Add symlink for libguestfs
         if [ -f /dev/.initramfs/live/vmlinuz0 ];
@@ -1411,6 +1478,11 @@ EOP
             tuned-adm profile $OVIRT_TUNED_PROFILE
         fi
 
+        #iscsi installs with hang when network service is killed
+        if [ -e "/dev/disk/by-label/Boot" ]; then
+            rm  /var/lock/subsys/network
+        fi
+
         if is_standalone; then
             return 0
         fi
@@ -1509,6 +1581,11 @@ status_ovirt_cim () {
     return $?
 }
 
+major_release() {
+    REL=`cat /etc/redhat-release | sed -r 's/.*release ([0-9]+).*/\1/'`
+    echo $REL
+}
+
 start_ovirt_kdump () {
     [ -f "$VAR_SUBSYS_OVIRT_cim" ] && exit 0
     {
@@ -1517,6 +1594,10 @@ start_ovirt_kdump () {
         touch $VAR_SUBSYS_OVIRT_KDUMP
 
         if is_persisted /etc/kdump.conf; then
+            if [[ ! -z $OVIRT_KDUMP_NFS && $(major_release) -ge 7 ]]; then
+                [[ ! -d //var/run/kdump-nfs ]] && mkdir /var/run/kdump-nfs
+                mount /var/run/kdump-nfs
+            fi
             service kdump start
         fi
 
