@@ -18,27 +18,33 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 # MA  02110-1301, USA.  A copy of the GNU General Public License is
 # also available at http://www.gnu.org/copyleft/gpl.html.
-
 """
 Storage Volume page of the installer
 """
+import os
 from ovirt.node import plugins, ui, valid
+from ovirt.node.utils import process
 from ovirt.node.exceptions import InvalidData
+from ovirt.node import presets
 
 
 class Plugin(plugins.NodePlugin):
     _model = {}
     _free_space = 0
+    _min_drive_size = 1295
     _fill = True
 
     def name(self):
-        return "Storage Sizes"
+        return _("Storage Sizes")
 
     def rank(self):
         return 40
 
     def model(self):
-        if not self._model:
+        drive_changed = (self._model["storage.install_drive"] !=
+                         self.__get_install_drive() if self._model
+                         else None)
+        if not self._model or drive_changed:
             self._model = self.__get_default_sizes()
             self._model["storage.data_size"] = "%s" %\
                                                self.__calculate_free_space()
@@ -62,9 +68,15 @@ class Plugin(plugins.NodePlugin):
                 }
 
     def ui_content(self):
-        ws = [ui.Header("header[0]", "Storage Volumes"),
+        ws = [ui.Header("header[0]", _("Storage Volumes")),
               ui.KeywordLabel("storage.drive_size", "Drive size: ")]
 
+        if not self.__enough_free_space():
+            ws.extend([ui.Notice("space.notice",
+                                 "Not enough space! Needs at least "
+                                 "1295MB for installation, %sMB "
+                                 "available" % self._drive_size)])
+
         if not self._fill:
             ws.extend([ui.KeywordLabel("storage.free_space",
                                        "Remaining Space: ")])
@@ -73,16 +85,17 @@ class Plugin(plugins.NodePlugin):
                             "following partitions in MB"),
                    ui.Checkbox("storage.fill_data", "Fill disk with Data " +
                                "partition", True),
-                   ui.Entry("storage.efi_size", "UEFI/Bios:", enabled=False),
-                   ui.Entry("storage.root_size", "Root & RootBackup:",
+                   ui.Entry("storage.efi_size", _("UEFI/Bios:"),
                             enabled=False),
-                   ui.Label("label[1]", "(2 partitions at %sMB each)" %
-                            self.model().get("storage.efi_size")),
+                   ui.Entry("storage.root_size", _("Root & RootBackup:"),
+                            enabled=False),
+                   ui.Label("label[1]", _("(2 partitions at %sMB each)") %
+                            self.model().get("storage.root_size")),
                    ui.Divider("divider[2]"),
-                   ui.Entry("storage.swap_size", "Swap:"),
-                   ui.Entry("storage.config_size", "Config:"),
-                   ui.Entry("storage.logging_size", "Logging:"),
-                   ui.Entry("storage.data_size", "Data:",
+                   ui.Entry("storage.swap_size", _("Swap MB:")),
+                   ui.Entry("storage.config_size", _("Config MB:")),
+                   ui.Entry("storage.logging_size", _("Logging MB:")),
+                   ui.Entry("storage.data_size", _("Data MB:"),
                             enabled=not self._fill),
                    ])
 
@@ -91,9 +104,15 @@ class Plugin(plugins.NodePlugin):
 
         self.widgets.add(ws)
         page = ui.Page("storage", ws)
-        page.buttons = [ui.QuitButton("button.quit", "Quit"),
-                        ui.Button("button.back", "Back"),
-                        ui.SaveButton("button.next", "Continue")]
+        page.buttons = [ui.QuitButton("button.quit", _("Quit")),
+                        ui.Button("button.back", _("Back"))]
+
+        if self.__enough_free_space():
+            can_continue = self.model() and self.__calculate_free_space() >= 0
+            page.buttons.extend([ui.SaveButton("button.next",
+                                               _("Continue"),
+                                               enabled=can_continue)])
+
         return page
 
     def on_change(self, changes):
@@ -144,13 +163,21 @@ class Plugin(plugins.NodePlugin):
 
     def __get_default_sizes(self):
         if self.application.args.dry:
-            self._drive_size = 42 * 1024
-            return {"storage.efi_size": "256",
-                    "storage.root_size": "50",
+            if os.geteuid() == 0:
+                cmd = "blockdev --getsize64 /dev/[sv]da"
+                stdout = process.check_output(cmd, shell=True)
+                self._drive_size = int(stdout) / 1024 / 1024
+            else:
+                # If we're not root and can't query the drive,
+                # pretend it's 5G
+                self._drive_size = 5242880
+            return {"storage.efi_size": "%s" % presets.BOOT_SIZE,
+                    "storage.root_size": "%s" % presets.ROOT_SIZE,
                     "storage.swap_size": "0",
                     "storage.config_size": "5",
                     "storage.logging_size": "2048",
                     "storage.data_size": "0",
+                    "storage.install_drive": self.__get_install_drive()
                     }
         from ovirtnode.storage import Storage
         stor = Storage()
@@ -162,7 +189,8 @@ class Plugin(plugins.NodePlugin):
                  "storage.logging_size": "%s" % stor.LOGGING_SIZE,
                  "storage.data_size": "%s" % "0",
                  "storage.free_space": "0 MB",
-                 "storage.drive_size": "%s MB" % self._drive_size
+                 "storage.drive_size": "%s MB" % self._drive_size,
+                 "storage.install_drive": self.__get_install_drive()
                  }
         return sizes
 
@@ -203,3 +231,12 @@ class Plugin(plugins.NodePlugin):
             free_space = 0
 
         return free_space
+
+    def __enough_free_space(self):
+        """
+        Determin if the available size is large enough to hold the installation
+        """
+        if self.application.args.dry:
+            return True
+        self._drive_size = self.__get_drives_size(self.__get_install_drive())
+        return self._drive_size > self._min_drive_size
