@@ -18,7 +18,7 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 # MA  02110-1301, USA.  A copy of the GNU General Public License is
 # also available at http://www.gnu.org/copyleft/gpl.html.
-from ovirt.node import config, base, utils, config, valid, log
+from ovirt.node import base, utils, config, valid, log
 from ovirt.node.config.network import NicConfig
 from ovirt.node.utils import fs
 from ovirt.node.utils.fs import File
@@ -227,8 +227,6 @@ class NIC(base.Base):
     def exists(self):
         """If this NIC currently exists in the system
 
-        >>> NIC("lo").exists()
-        True
         """
         return self.ifname in all_ifaces()
 
@@ -243,9 +241,6 @@ class NIC(base.Base):
     def has_link(self):
         """Determin if L1 is up on a given interface
 
-        >>> NIC("lo").has_link()
-        True
-
         Args:
             ifname: The interface to be checked
         Returns:
@@ -265,12 +260,11 @@ class NIC(base.Base):
                 LOGGER.debug("Failed to retrieve carrier with NM")
 
         # Fallback
-        has_carrier = False
-        try:
-            content = File("/sys/class/net/%s/carrier" % self.ifname).read()
-            has_carrier = "1" in content
-        except:
-            LOGGER.debug("Carrier down for %s" % self.ifname)
+        process.call(["ip", "link", "set", "dev", self.ifname, "up"])
+
+        content = File("/sys/class/net/%s/carrier" % self.ifname).read()
+        has_carrier = "1" in content
+
         return has_carrier
 
     def ipv4_address(self):
@@ -313,15 +307,15 @@ class NIC(base.Base):
         # Fallback
         cmd = "ip -o addr show {ifname}".format(ifname=self.ifname)
         for line in process.pipe(cmd, shell=True).split("\n"):
-            matches = re.search("\s(inet[6]?)\s(.+)/([^\s]+).*scope ([^\s]+).*",
-                                line)
+            matches = re.search("\s(inet[6]?)\s(.+)/([^\s]+)"
+                                ".*scope ([^\s]+).*", line)
             if matches and matches.groups():
                 family, addr, mask, scope = matches.groups()
                 if family not in families:
                     continue
                 if family == "inet":
                     mask = calcDottedNetmask(mask)
-                if scope == "global" or addresses[family].address == None:
+                if scope == "global" or addresses[family].address is None:
                     addresses[family] = IPAddress(addr, mask, scope)
 
         return addresses
@@ -407,6 +401,7 @@ class TaggedNIC(NIC):
     """A class to provide easy access to tagged NICs
     """
     vlan_nic = None
+    parent_nic = None
 
     def __init__(self, parent_nic, vlanid):
         """A unified API for tagged NICs
@@ -415,6 +410,7 @@ class TaggedNIC(NIC):
         """
         slave_ifname = "%s.%s" % (parent_nic.ifname, vlanid)
         super(TaggedNIC, self).__init__(parent_nic.ifname)
+        self.parent_nic = parent_nic
         self.vlan_nic = NIC(slave_ifname)
         self.config = self.vlan_nic.config
 
@@ -454,6 +450,9 @@ class TaggedNIC(NIC):
     def has_vlans(self):
         raise RuntimeError("Nested tagging is not allowed. Is it?")
 
+    def identify(self):
+        self.parent_nic.identify()
+
     def __str__(self):
         pairs = {"vlan": self.vlan_nic.ifname,
                  "parent": self.ifname}
@@ -475,6 +474,14 @@ class BondedNIC(NIC):
         for slave in self.slave_nics:
             slave.identify()
 
+    @property
+    def slaves(self):
+        return Bonds().slaves(self.ifname)
+
+    @property
+    def mode(self):
+        return Bonds().mode(self.ifname)
+
     def __str__(self):
         return self.build_str(["ifname", "slave_nics"])
 
@@ -542,7 +549,18 @@ class NodeNetwork(base.Base):
                                            n.startswith("virbr") or
                                            n.startswith("phy"))]
 
-    def build_nic_model(self, ifname):
+    def build_nic_model(self, ifname, filter_slaveless=False,
+                        filter_configured=False):
+        """Return an object for an ifname
+
+        Args:
+          ifname: ifname for the object to build
+          filter_slaves: Only return bonds if they have slaves
+          filter_configured: Only return objects if they are unconfigured
+
+        Returns:
+          A NIC (or subclass) instance.
+        """
         mnet = config.defaults.Network().retrieve()
         mlayout = config.defaults.NetworkLayout().retrieve()
         mbond = config.defaults.NicBonding().retrieve()
@@ -552,11 +570,14 @@ class NodeNetwork(base.Base):
         layout = mlayout["layout"]
 
         nic = NIC(ifname)
+
         self.logger.debug("Building model for: %s" % nic)
 
-        if ifname == bond_name:
+        if ifname == bond_name or nic.typ == "bond":
             self.logger.debug(" Is bond master")
             nic = BondedNIC(nic, bond_slaves)
+            nic.slave_nics = [NIC(n) for n in nic.slaves] if not \
+                nic.slave_nics else nic.slave_nics
 
         if ifname == bootif:
             self.logger.debug(" Is bootif")
@@ -568,14 +589,22 @@ class NodeNetwork(base.Base):
                 self.logger.debug(" Is bridged")
                 nic = BridgedNIC(nic)
 
-        if ifname in bond_slaves:
+        if nic.is_configured() and filter_configured:
+            # Don not return configured NICs
+            nic = None
+        elif ifname in bond_slaves:
+            # Don't return slaves (of bonds)
+            nic = None
+        elif isinstance(nic, BondedNIC) and not nic.slaves and \
+                filter_slaveless:
+            # Bond device with no slaves. Don't show it
             nic = None
 
         self.logger.debug("Concluded Model: %s" % nic)
 
         return nic
 
-    def nics(self):
+    def nics(self, filter_slaveless=False, filter_configured=False):
         """
         >>> model = NodeNetwork()
         """
@@ -595,7 +624,8 @@ class NodeNetwork(base.Base):
         candidates = {}
 
         for nic in nics + vlans:
-            candidate = self.build_nic_model(nic.ifname)
+            candidate = self.build_nic_model(nic.ifname, filter_slaveless,
+                                             filter_configured)
             if candidate:
                 candidates[candidate.ifname] = candidate
 
@@ -616,9 +646,11 @@ class NodeNetwork(base.Base):
         return candidate
 
     def is_configured(self):
-        """The NodeNetwork is either configered when we or a mgmt instance configured it
+        """The NodeNetwork is either configered when we or a mgmt instance
+        configured it
         """
-        mgmtInterface = config.defaults.Management().retrieve()["managed_ifnames"]
+        mgmtInterface = config.defaults.Management().retrieve()[
+            "managed_ifnames"]
         return any([self.configured_nic(), mgmtInterface])
 
 
@@ -750,7 +782,7 @@ def reset_resolver():
 
 
 class Vlans(base.Base):
-    """A class to offer a convenience api to the vconfig file
+    """A class to offer a convenience api for vlans
     """
     cfgfilename = "/proc/net/vlan/config"
 
@@ -769,8 +801,8 @@ class Vlans(base.Base):
                 if not data_block:
                     continue
                 vdev, vid, hdev = [field.strip()
-                                 for field in line.split("|")]
-                if not hdev in vlans:
+                                   for field in line.split("|")]
+                if hdev not in vlans:
                     vlans[hdev] = []
                 vlans[hdev].append((vdev, vid))
         except IOError as e:
@@ -811,7 +843,7 @@ class Vlans(base.Base):
         if not self.is_vlan_device(ifname):
             raise RuntimeError("Can no delete '%s', is no vlan device" %
                                ifname)
-        process.call(["vconfig", "rem", ifname])
+        process.call(["ip", "link", "del", ifname])
 
 
 class Bridges(base.Base):
@@ -833,6 +865,8 @@ class Bonds(base.Base):
     """Convenience API to access some bonding related stuff
     """
     bonding_masters_filename = "/sys/class/net/bonding_masters"
+    bond_slaves_path = "/sys/class/net/%s/bonding/slaves"
+    bond_mode_path = "/sys/class/net/%s/bonding/mode"
 
     def is_enabled(self):
         """If bonding is enabled
@@ -850,7 +884,27 @@ class Bonds(base.Base):
     def is_bond(self, ifname):
         """Determins if ifname is a bond device
         """
-        return ifname in self.ifnames()
+        return File(self.bond_slaves_path % ifname).exists()
+
+    def slaves(self, ifname):
+        """Find all slaves of the bond master ifname
+        """
+        path = self.bond_slaves_path % ifname
+        slaves = []
+        if self.is_bond(ifname):
+            slaves = File(path).read().split()
+        return slaves
+
+    def mode(self, ifname, text_only=True):
+        """Return the mode used for this bond
+
+        Args:
+         text_only: If only the textual mode representation shall be returned
+        """
+        mode = File(self.bond_mode_path % ifname).read()
+        if text_only:
+            mode = mode.split()[0]
+        return mode
 
     def delete_all(self):
         """Deletes all bond devices
@@ -864,6 +918,6 @@ class Bonds(base.Base):
         if not self.is_bond(mifname):
             raise RuntimeError("Can no delete '%s', it is no bond master" %
                                mifname)
-        #process.call(["ip", "link", "set", "dev", mifname, "down"])
-        #process.call(["ip", "link", "delete", mifname, "type", "bond"])
+        # process.call(["ip", "link", "set", "dev", mifname, "down"])
+        # process.call(["ip", "link", "delete", mifname, "type", "bond"])
         fs.File(self.bonding_masters_filename).write("-%s" % mifname)
