@@ -37,8 +37,9 @@ import libvirt
 import logging
 import grp
 import pwd
+import time
 from ovirt.node.config import defaults
-from ovirt.node.utils import process
+from ovirt.node.utils import process, hooks
 import ovirt.node.utils.system as osystem
 from ovirt.node.utils.console import TransactionProgress, Transaction
 from ovirtnode.network import *
@@ -74,12 +75,14 @@ OVIRT_CONFIG_FILES = [ "/etc/rsyslog.conf",
                        "/etc/default/ovirt",
                        "/etc/sysconfig/network",
                        "/etc/collectd.conf",
-                       "/etc/libvirt/qemu/networks",
+                       "/etc/libvirt/qemu/",
                        "/etc/ssh/sshd_config",
                        "/etc/pki",
                        "/etc/iscsi/initiatorname.iscsi",
                        "/etc/logrotate.d/ovirt-node",
-                       "/var/lib/random-seed" ]
+                       "/var/lib/random-seed",
+                       "/var/lib/glusterd",
+                       "/etc/sysconfig/virt-who"]
 
 OVIRT_VARS = {}
 # Parse all OVIRT_* variables
@@ -538,21 +541,8 @@ def mount_liveos():
             return True
 
 def mount_efi(target="/liveos/efi"):
-    if os.path.ismount(target):
-        return True
-    if is_iscsi_install() or findfs("Boot"):
-        efi_part = findfs("Boot")
-    else:
-        efi_part = findfs("Root")
-    efi_part = efi_part[:-1] + "1"
-    if not os.path.exists(target):
-        if not system("mkdir -v -p %s" % target):
-            logger.warning("Unable to create mount target for EFI partition")
-    if system("mount -t vfat %s %s" % (efi_part, target)):
-        return True
-    else:
-        logger.error("Unable to mount EFI partition")
-        return False
+    # Moved to the new codebase
+    osystem.mount_efi(target)
 
 # mount config partition
 # /config for persistance
@@ -628,10 +618,14 @@ def connect_iscsi_root():
                         augtool("set",
                                 "/files/etc/default/ovirt/OVIRT_BOOTIF",
                                 "\"%s\"" % value)
-                    if "BOOTPROTO" in key:
+                    elif "BOOTPROTO" in key:
                         augtool("set",
                                 "/files/etc/default/ovirt/OVIRT_BOOTPROTO",
                                 "\"%s\"" % value)
+                    elif "ISCSI" in key:
+                        augtool("set",
+                                "/files/etc/default/ovirt/%s" % key,
+                                "\"%s\"" % value)
                 except:
                     pass
             f.close()
@@ -651,6 +645,8 @@ def connect_iscsi_root():
                 system(login_cmd)
                 logger.info("Restarting iscsi service")
                 system("service iscsi restart")
+                # let login settle devices
+                time.sleep(5)
                 system("pvscan")
                 system("vgscan")
                 system("vgchange -ay")
@@ -852,6 +848,59 @@ def ovirt_store_config(files):
             rc = rc and True
     return rc
 
+def ovirt_store_config_retnum(filename):
+    if is_stateless():
+        return True
+    if not os.path.ismount("/config"):
+        logger.error("/config is not mounted")
+        raise SystemExit(2)
+    filename = os.path.abspath(filename)
+
+    if os.path.isdir(filename):
+        # ensure that, if this is a directory
+        # that it's not already persisted
+        if os.path.isdir("/config/" + filename):
+            logger.warn("Directory already persisted: " + filename)
+            logger.warn("You need to unpersist its child directories " +
+                        "and/or files and try again.")
+            raise SystemExit(3)
+    elif os.path.isfile(filename):
+        # if it's a file then make sure it's not already persisted
+        if os.path.isfile("/config/" + filename):
+            cksumroot=cksum(filename)
+            cksumstored=cksum("/config" + filename)
+            if cksumroot == cksumstored:
+                logger.warn("File already persisted: " + filename)
+                raise SystemExit(4)
+            else:
+                # persistent copy needs refresh
+                if system("umount -n " + filename + " 2> /dev/null"):
+                    system("rm -f /config"+ filename)
+    else:
+        # skip if file does not exist
+        logger.warn("Skipping, file '" + filename + "' does not exist")
+        raise SystemExit(5)
+
+    # skip if already bind-mounted
+    if not check_bind_mount(filename):
+        dirname = os.path.dirname(filename)
+        system("mkdir -p /config/" + dirname)
+        if system("cp -a " + filename + " /config"+filename):
+            system("umount "+filename)
+            if not system("mount -n --bind /config"+filename+ " " + \
+                          filename):
+                logger.error("Failed to persist: " + filename)
+                raise SystemExit(1)
+            else:
+                logger.info("File: " + filename + " persisted")
+    # register in /config/files used by rc.sysinit
+    ret = system_closefds("grep -q \"^$" + filename +"$\" " + \
+                          " /config/files 2> /dev/null")
+    if ret > 0:
+        system_closefds("echo "+filename+" >> /config/files")
+        logger.info("Successfully persisted: " + filename)
+
+
 def ovirt_store_config_atomic(filename, source=None):
     rc = True
     persist_it = True
@@ -1116,6 +1165,7 @@ def finish_install():
     cmd.communicate()
 
     if is_iscsi_install() or findfs("BootUpdate"):
+        mount_config()
         boot_update_dev = findfs("BootUpdate")
         boot_dev = findfs("Boot")
         e2label_bootbackup_cmd = "e2label '%s' BootBackup" % boot_dev
@@ -1127,28 +1177,25 @@ def finish_install():
 
     # fix SELinux
     logging_dev = findfs("LOGGING")
-    logging_mount_cmd = ("grep %s /proc/mounts | grep writable |" +
-                         "awk '{print $2}'") % logging_dev
+    assert logging_dev, "Failed to find logging device"
+    logging_mount_cmd = "mkdir -p /var/log ; mount %s /var/log" % logging_dev
     logging_mount = subprocess_closefds(logging_mount_cmd, shell=True,
                                         stdout=PIPE, stderr=STDOUT)
-    (logging_mount_output, dummy) = logging_mount.communicate()
-    system("chcon -R system_u:object_r:var_log_t:s0 %s" % logging_mount_output)
-    system("chcon -R system_u:object_r:auditd_log_t:s0 %s/audit/" %
-           logging_mount_output.rstrip())
+    logging_mount.communicate()
+    # First restore all
+    system("restorecon -rv /var/log")
+    # Now handle exceptions
+    system("chcon -R system_u:object_r:virt_cache_t:s0 /var/log/core/")
+    # Either removes the layering mount, or fails
+    system("umount /var/log")
 
     # run post-install hooks
     # e.g. to avoid reboot loops using Cobbler PXE only once
     # Cobbler XMLRPC post-install trigger (XXX is there cobbler SRV record?):
     # wget "http://192.168.50.2/cblr/svc/op/trig/mode/post/system/$(hostname)"
     #   -O /dev/null
-    hookdir="/etc/ovirt-config-boot.d"
-    for hook in os.listdir(hookdir):
-        if is_auto_install():
-            hookscript = os.path.join(hookdir, hook)
-            if hook.endswith(".py"):
-                system_closefds("python " + hookscript)
-            else:
-                system_closefds(hookscript + " &> /dev/null")
+    if is_auto_install():
+        hooks.Hooks.post_auto_install()
     for f in ["/etc/ssh/ssh_host%s_key" % t for t in ["", "_dsa", "_rsa"]]:
         ovirt_store_config(f)
         ovirt_store_config("%s.pub" % f)
@@ -1318,14 +1365,30 @@ def wipe_partitions(_drive):
         if "HostVG" in lv:
             system_closefds("dmsetup remove " +lv + " &>>" + OVIRT_TMP_LOGFILE)
     logger.info("Wiping old boot sector")
-#    system_closefds("dd if=/dev/zero of=\""+ drive +"\" bs=1024K count=1 &>>" + OVIRT_TMP_LOGFILE)
+    system_closefds("parted -s \""+ drive +"\" mklabel msdos &>>" + OVIRT_TMP_LOGFILE)
+    system_closefds("parted -s \""+ drive +"\" mklabel gpt &>>" + OVIRT_TMP_LOGFILE)
     system_closefds("parted -s \""+ drive +"\" mklabel loop &>>" + OVIRT_TMP_LOGFILE)
-    system_closefds("wipefs -a \""+ drive +"\" &>>" + OVIRT_TMP_LOGFILE)
+    system_closefds("which systemctl 2>/dev/null >&2 && wipefs -af \""+ drive +"\" >>" + OVIRT_TMP_LOGFILE + "2>&1")
+    system_closefds("which systemctl 2>/dev/null >&2 || wipefs -a \""+ drive +"\"  >>" + OVIRT_TMP_LOGFILE + "2>&1")
+    system_closefds("dd if=/dev/zero of=\""+ drive +"\" bs=1024K count=1 &>>" + OVIRT_TMP_LOGFILE)
     ## zero out the GPT secondary header
-    #logger.info("Wiping secondary gpt header")
-    #disk_kb = subprocess_closefds("sfdisk -s \""+ drive +"\" 2>/dev/null", shell=True, stdout=PIPE, stderr=STDOUT)
-    #disk_kb_count = disk_kb.stdout.read()
-    #system_closefds("dd if=/dev/zero of=\"" +drive +"\" bs=1024 seek=$(("+ disk_kb_count+" - 1)) count=1 &>>" + OVIRT_TMP_LOGFILE)
+    logger.info("Wiping secondary gpt header")
+    disk_kb = subprocess_closefds("sfdisk -s \""+ drive +"\" 2>/dev/null", shell=True, stdout=PIPE, stderr=STDOUT)
+    disk_kb_count = disk_kb.stdout.read()
+    system_closefds("dd if=/dev/zero of=\"" +drive +"\" bs=1024 seek=$(("+ disk_kb_count+" - 1)) count=1 &>>" + OVIRT_TMP_LOGFILE)
+
+    # Potentially wipe out new GPT header locations
+    logger.info("Wiping GPT header")
+    system_closefds("dd if=/dev/zero of=\"" + drive +
+                    "\" bs=4096 count=35 &>>" + OVIRT_TMP_LOGFILE)
+    logger.info("Wiping secondary gpt header")
+    disk_kb = subprocess_closefds("blockdev --getsz \"" + drive +
+                                  "\" 2>/dev/null", shell=True, stdout=PIPE,
+                                  stderr=STDOUT)
+    disk_kb_count = disk_kb.stdout.read()
+    system_closefds("dd if=/dev/zero of=\"" + drive +
+                    "\" bs=4096 seek=$((" + disk_kb_count +
+                    " * 512/4096 - 35)) count=35 &>>" + OVIRT_TMP_LOGFILE)
     system_closefds("sync")
 
 def test_ntp_configuration(self):
@@ -1387,6 +1450,7 @@ def check_existing_hostvg(install_dev, vg_name=None):
 def translate_multipath_device(dev):
     #trim so that only sdX is stored, but support passing /dev/sdX
     logger.debug("Translating: %s" % dev)
+    multipath_dev = dev
     if dev is None:
         return False
     if "/dev/mapper" in dev:
@@ -1395,8 +1459,8 @@ def translate_multipath_device(dev):
         cciss_dev_cmd = "cciss_id " + dev
         cciss_dev = subprocess_closefds(cciss_dev_cmd, shell=True, stdout=PIPE, stderr=STDOUT)
         output, err = cciss_dev.communicate()
-        dev = "/dev/mapper/" + output.strip()
-    dm_dev_cmd = "multipath -ll '%s' | egrep dm-[0-9]+" % dev
+        multipath_dev = "/dev/mapper/" + output.strip()
+    dm_dev_cmd = "multipath -ll '%s' | egrep dm-[0-9]+" % multipath_dev
     dm_dev = subprocess_closefds(dm_dev_cmd, shell=True, stdout=PIPE, stderr=STDOUT)
     (dm_dev_output, dummy) = dm_dev.communicate()
     if dm_dev.returncode > 0:
@@ -1441,20 +1505,32 @@ def add_user(username, shell="/usr/libexec/ovirt-admin-shell", group="",
         system_closefds(cmd)
 
 def get_installed_version_number():
-    if mount_liveos():
-        existing_version = open("/liveos/version")
-        existing_install = {}
-        for line in existing_version.readlines():
-            try:
-                key, value = line.strip().split("=")
-                value = value.replace("'", "")
-                existing_install[key] = value
-            except:
-                pass
+    #rhbz 1167240 restoring mount situation
+    retval = False
+    unmount = False
+    if not os.path.ismount("/liveos"):
+        unmount = True
+    if mount_liveos() and os.path.exists("/liveos/version"):
+        with open("/liveos/version") as existing_version:
+            existing_install = {}
+            for line in existing_version.readlines():
+                try:
+                    key, value = line.strip().split("=")
+                    value = value.replace("'", "")
+                    existing_install[key] = value
+                except:
+                    pass
+
         if existing_install.has_key("VERSION") and existing_install.has_key("RELEASE"):
-            return [existing_install["VERSION"],existing_install["RELEASE"]]
-        else:
-            return False
+            retval = [existing_install["VERSION"],existing_install["RELEASE"]]
+
+    if unmount:
+            if system("umount /liveos &>/dev/null"):
+                logger.debug("unmounted liveos")
+            else:
+                logger.error("Wasnt able to restore mounting")
+
+    return retval
 
 def get_media_version_number():
     new_install = {}
@@ -1478,7 +1554,6 @@ def get_media_version_number():
     return False
 
 def findfs(label):
-    system("partprobe /dev/mapper/*")
     system("udevadm settle")
     blkid_cmd = "/sbin/blkid -c /dev/null -l -o device -t LABEL=\"" + label + "\""
     blkid = subprocess_closefds(blkid_cmd, shell=True, stdout=PIPE, stderr=STDOUT)
@@ -1495,6 +1570,8 @@ def system(command):
     if system_cmd.returncode == 0:
         return True
     else:
+        logger.debug("Command '%s' failed with return code %s\nSTDERR: %s" %
+                     (command, system_cmd.returncode, err))
         return False
 
 def password_check(password_1, password_2, min_length=1):
@@ -1531,126 +1608,21 @@ def get_logrotate_size():
     size = int(size) * multiplier
     return str(size)
 
-def get_cpu_flags():
-    cpuflags_cmd = "cat /proc/cpuinfo |grep ^flags|tail -n 1"
-    cpuflags_lookup = subprocess_closefds(cpuflags_cmd, shell=True, stdout=PIPE, stderr=STDOUT)
-    output, err = cpuflags_lookup.communicate()
-    return output.strip()
-
 def kvm_enabled():
-    try:
-        conn = libvirt.openReadOnly(None)
-        libvirt_capabilities = conn.getCapabilities()
-    except:
-        return 0
-    # Look for a KVM mdomain
-    if re.search("domain type=.kvm", libvirt_capabilities):
-        return 1
-    else:
-        return 2
+    import ovirt.node.utils.virt as v
+    return v.hardware_is_enabled()
 
 def virt_cpu_flags_enabled():
-    cpuflags = get_cpu_flags()
-    if "vmx" in cpuflags or "svm" in cpuflags:
-        return True
-    else:
-        return False
+    import ovirt.node.utils.virt as v
+    return v.hardware_is_available()
 
 def get_virt_hw_status():
-    hwvirt_msg = ""
-    kvm_status = kvm_enabled()
-    if kvm_status == 0:
-        return "(Failed to Establish Libvirt Connection)"
-    elif kvm_status == 1:
-        logger.info("Hardware virtualization detected")
-    elif kvm_status == 2:
-        hwvirt_msg = "Virtualization hardware is unavailable."
-        if virt_cpu_flags_enabled():
-            hwvirt_msg = "(Virtualization hardware detected but disabled)"
-        else:
-            hwvirt_msg = "(Virtualization hardware was not detected)"
-    return hwvirt_msg
-
+    import ovirt.node.utils.virt as v
+    return v.hardware_status()
 
 def cpu_details():
-    status_msg = ""
-    cpu_info_cmd = "cat /proc/cpuinfo"
-    cpu_info = subprocess.Popen(cpu_info_cmd, shell=True, stdout=PIPE, stderr=STDOUT)
-    cpu_info = cpu_info.stdout.read().strip()
-    cpu_dict = {}
-    for line in cpu_info.splitlines():
-        try:
-            key, value = line.split(":")
-            cpu_dict[key.replace("\t","")] = value
-        except:
-            pass
-    # get capabilities from libvirt
-    try:
-        conn = libvirt.openReadOnly(None)
-        libvirt_capabilities = conn.getCapabilities()
-    except:
-        return "(Failed to Establish Libvirt Connection)"
-    dom = parseString(libvirt_capabilities)
-    # get cpu section
-    cpu = parseString(dom.getElementsByTagName('cpu')[0].toxml())
-    try:
-        vendorTag = cpu.getElementsByTagName('vendor')[0].toxml()
-        cpu_vendor = vendorTag.replace('<vendor>','').replace('</vendor>','')
-    except:
-        cpu_vendor = "Unknown Vendor"
-    try:
-        modelTag = cpu.getElementsByTagName('model')[0].toxml()
-        cpu_model = modelTag.replace('<model>','').replace('</model>','')
-    except:
-        if cpu_vendor == "Unknown Vendor":
-            cpu_model = ""
-        else:
-            cpu_model = "Unknown Model"
-    try:
-        host = dom.getElementsByTagName('host')[0]
-        cells = host.getElementsByTagName('cells')[0]
-        total_cpus = cells.getElementsByTagName('cpu').length
-
-        socketIds = []
-        siblingsIds = []
-
-        socketIds = [proc.getAttribute('socket_id')
-                     for proc in cells.getElementsByTagName('cpu')
-                     if proc.getAttribute('socket_id') not in socketIds]
-
-        siblingsIds = [proc.getAttribute('siblings')
-                       for proc in cells.getElementsByTagName('cpu')
-                       if proc.getAttribute('siblings') not in siblingsIds]
-        cpu_topology = "OK"
-    except:
-        cpu_topology = "Unknown"
-    status_msg += "CPU Name: %s\n" % cpu_dict["model name"].replace("  "," ")
-    status_msg += "CPU Type: %s %s\n" % (cpu_vendor, cpu_model)
-    if kvm_enabled() == 1 and virt_cpu_flags_enabled():
-        status_msg += "Virtualization Extensions Enabled: Yes\n"
-    else:
-        status_msg += "Virtualization Extensions Enabled: \n%s\n" \
-            % get_virt_hw_status()
-    if cpu_vendor == "Intel":
-        if "nx" in cpu_dict["flags"]:
-            status_msg += "NX Flag: Yes\n"
-        else:
-            status_msg += "NX Flag: No\n"
-    elif cpu_vendor == "AMD":
-        if "evp" in cpu_dict["flags"]:
-            status_msg += "EVP Flag: Yes\n"
-        else:
-            status_msg += "EVP Flag: No\n"
-    if cpu_topology == "Unknown":
-        status_msg += "Unable to determine CPU Topology"
-    else:
-        cpu_sockets = len(set(socketIds))
-        status_msg += "CPU Sockets: %s\n" % cpu_sockets
-        cpu_cores = len(set(siblingsIds))
-        status_msg += "CPU Cores: %s\n" % cpu_cores
-        cpu_threads = total_cpus
-        status_msg += "CPU Threads: %s\n" % cpu_threads
-    return status_msg
+    import ovirt.node.utils.system as s
+    return s.cpu_details()
 
 def get_ssh_hostkey(variant="rsa"):
     fn_hostkey = "/etc/ssh/ssh_host_%s_key.pub" % variant
