@@ -27,6 +27,7 @@ import logging
 import subprocess
 import shlex
 from ovirtnode.iscsi import set_iscsi_initiator
+from ovirt.node import presets
 
 logger = logging.getLogger(__name__)
 
@@ -36,8 +37,8 @@ class Storage:
         logger.propagate = False
         OVIRT_VARS = _functions.parse_defaults()
         self.overcommit = 0.5
-        self.BOOT_SIZE = 512
-        self.ROOT_SIZE = 512
+        self.BOOT_SIZE = presets.BOOT_SIZE
+        self.ROOT_SIZE = presets.ROOT_SIZE
         self.CONFIG_SIZE = 5
         self.LOGGING_SIZE = 2048
         self.EFI_SIZE = 256
@@ -74,7 +75,8 @@ class Storage:
                                 skip = True
                                 break
                         if not skip:
-                            self.HOSTVGDRIVE += "%s," % translated_disk
+                            self.HOSTVGDRIVE += ("%s," % translated_disk) \
+                                if translated_disk else ""
             else:
                 self.ROOTDRIVE = _functions.translate_multipath_device(
                                     _functions.OVIRT_VARS["OVIRT_INIT"])
@@ -113,7 +115,7 @@ class Storage:
                                  "of: %s") % (i, self.__dict__[i_short]))
                     print (("\n%s is smaller than minimum required size of: " +
                           "%s") % (i, self.__dict__[i_short]))
-                    return False
+                    #return False
                 logger.info(("Setting value for %s to %s " %
                            (self.__dict__[i_short], _functions.OVIRT_VARS[i])))
                 i_short = i_short.replace("MIN_", "")
@@ -239,14 +241,6 @@ class Storage:
         logger.debug("Rereading pt")
         _functions.system("sync")
         if "dev/mapper" in drive:
-            # kpartx -a -p p "$drive"
-            # XXX fails with spaces in device names (TBI)
-            # ioctl(3, DM_TABLE_LOAD, 0x966980) = -1 EINVAL (Invalid argument)
-            # create/reload failed on 0QEMU   QEMU HARDDISK  drive-scsi0-0-0p1
-            _functions.system("kpartx -a '%s'" % drive)
-            _functions.system("partprobe")
-            # partprobe fails on cdrom:
-            # Error: Invalid partition table - recursive partition on /dev/sr0.
             _functions.system("service multipathd reload")
             _functions.system("multipath -r &>/dev/null")
             # wait for device to exit
@@ -434,7 +428,8 @@ class Storage:
                     self.ROOTDRIVE = self.BOOTDRIVE
                 elif self.ISCSIDRIVE == drv:
                     parted_cmd = ("parted \"" + drv + "\" -s \"mkpart " +
-                                  "primary ext2 512M -1\"")
+                                  "primary ext2 " + str(self.ROOT_SIZE * 2) +
+                                  " -1\"")
                     logger.debug(parted_cmd)
                     _functions.system(parted_cmd)
                     hostvgpart = "3"
@@ -508,7 +503,7 @@ class Storage:
             drv_count = drv_count + 1
         if self.SWAP_SIZE > 0:
             logger.info("Creating swap partition")
-            _functions.system("lvcreate --name Swap --size " + \
+            _functions.system("yes | lvcreate --name Swap --size " + \
                               str(self.SWAP_SIZE) + "M /dev/HostVG")
             _functions.system("mkswap -L \"SWAP\" /dev/HostVG/Swap")
             _functions.system_closefds("echo \"/dev/HostVG/Swap swap swap " +
@@ -520,14 +515,14 @@ class Storage:
                                 "\" >> /etc/ovirt-crypttab")
         if self.CONFIG_SIZE > 0:
             logger.info("Creating config partition")
-            _functions.system("lvcreate --name Config --size " +
+            _functions.system("yes | lvcreate --name Config --size " +
                     str(self.CONFIG_SIZE) + "M /dev/HostVG")
             _functions.system("mke2fs -j -t ext4 /dev/HostVG/Config " + \
                               "-L \"CONFIG\"")
             _functions.system("tune2fs -c 0 -i 0 /dev/HostVG/Config")
         if self.LOGGING_SIZE > 0:
             logger.info("Creating log partition")
-            _functions.system("lvcreate --name Logging --size " +
+            _functions.system("yes | lvcreate --name Logging --size " +
                     str(self.LOGGING_SIZE) + "M /dev/HostVG")
             _functions.system("mke2fs -j -t ext4 /dev/HostVG/Logging " + \
                               "-L \"LOGGING\"")
@@ -538,12 +533,12 @@ class Storage:
         use_data = 1
         if self.DATA_SIZE == -1:
             logger.info("Creating data partition with remaining free space")
-            _functions.system("lvcreate --name Data -l 100%FREE /dev/HostVG")
+            _functions.system("yes | lvcreate --name Data -l 100%FREE /dev/HostVG")
             use_data = 0
         elif self.DATA_SIZE > 0:
             logger.info("Creating data partition")
-            _functions.system("lvcreate --name Data --size " + \
-                              str(self.DATA_SIZE) + "M /dev/HostVG")
+            _functions.system("yes | lvcreate --name Data --size " + \
+                                       str(self.DATA_SIZE) + "M /dev/HostVG")
             use_data = 0
         if use_data == 0:
             _functions.system("mke2fs -j -t ext4 /dev/HostVG/Data -L \"DATA\"")
@@ -673,7 +668,7 @@ class Storage:
 
         if self.SWAP2_SIZE > 0:
             logger.info("Creating swap2 partition")
-            lv_cmd = ("lvcreate --name Swap2 --size \"" +
+            lv_cmd = ("yes | lvcreate --name Swap2 --size \"" +
                       str(self.SWAP2_SIZE) + "M\" /dev/AppVG")
             logger.debug(lv_cmd)
             _functions.system(lv_cmd)
@@ -690,12 +685,12 @@ class Storage:
         use_data = "1"
         if self.DATA2_SIZE == -1:
             logger.info("Creating data2 partition with remaining free space")
-            _functions.system("lvcreate --name Data2 -l 100%FREE /dev/AppVG")
+            _functions.system("yes | lvcreate --name Data2 -l 100%FREE /dev/AppVG")
             use_data = 0
         elif self.DATA2_SIZE > 0:
             logger.info("Creating data2 partition")
-            _functions.system("lvcreate --name Data2 --size " + \
-                              str(self.DATA2_SIZE) +
+            _functions.system("yes | lvcreate --name Data2 --size " + \
+                                       str(self.DATA2_SIZE) +
                    "M /dev/AppVG")
             use_data = 0
 
@@ -869,7 +864,7 @@ class Storage:
                          str(self.RootBackup_end) + "M\"")
             logger.debug(parted_cmd)
             _functions.system(parted_cmd)
-            _functions.system("sync ; udevadm settle ; partprobe")
+            _functions.system("sync ; udevadm settle")
             parted_cmd = ("parted \"" + self.ROOTDRIVE +
                          "\" -s \"set 2 boot on\"")
             logger.debug(parted_cmd)
@@ -882,10 +877,12 @@ class Storage:
             if not os.path.exists(partroot):
                 partroot = self.ROOTDRIVE + "p2"
                 partrootbackup = self.ROOTDRIVE + "p3"
+            _functions.system("umount -l " + partroot)
             _functions.system("mke2fs \"" + partroot + "\" -L Root")
             _functions.system("tune2fs -c 0 -i 0 \"" + partroot + "\"")
             _functions.system("ln -snf \"" + partrootbackup +
                    "\" /dev/disk/by-label/RootBackup")
+            _functions.system("umount -l " + partrootbackup)
             _functions.system("mke2fs \"" + partrootbackup + \
                               "\" -L RootBackup")
             _functions.system("tune2fs -c 0 -i 0 \"" + partrootbackup + "\"")
@@ -1007,7 +1004,7 @@ def handle_fakeraid(device):
 
 def storage_auto():
     storage = Storage()
-    if not _functions.OVIRT_VARS["OVIRT_INIT"] == "":
+    if _functions.OVIRT_VARS.get("OVIRT_INIT"):
         #force root install variable for autoinstalls
         _functions.OVIRT_VARS["OVIRT_ROOT_INSTALL"] = "y"
         if _functions.check_existing_hostvg("") or \
